@@ -6,11 +6,11 @@ https://github.com/ijl/orjson
 还有
 https://github.com/ultrajson/ultrajson
 """
-
-import ujson
+from pyefun.核心支持库.公用函数 import _动态导包
 
 
 def json到文本(data, html编码=True, ascii编码=False, 斜杠转义=True, 缩进=0):
+    ujson = _动态导包("ujson")
     return ujson.dumps(data,
                        encode_html_chars=html编码,
                        ensure_ascii=ascii编码,
@@ -19,4 +19,6 @@ def json到文本(data, html编码=True, ascii编码=False, 斜杠转义=True, 
 
 
 def json加载(data):
+    ujson = _动态导包("ujson")
     return ujson.loads(data)
+
